"use strict";
const graphql_server_core_1 = require("graphql-server-core");
const GraphiQL = require("graphql-server-module-graphiql");
function graphqlKoa(options) {
    if (!options) {
        throw new Error('Apollo Server requires options.');
    }
    if (arguments.length > 1) {
        throw new Error(`Apollo Server expects exactly one argument, got ${arguments.length}`);
    }
    return (ctx) => {
        return graphql_server_core_1.runHttpQuery([ctx], {
            method: ctx.request.method,
            options: options,
            query: ctx.request.method === 'POST' ? ctx.request.body : ctx.request.query,
        }).then((gqlResponse) => {
            ctx.set('Content-Type', 'application/json');
            ctx.body = gqlResponse;
        }, (error) => {
            if ('HttpQueryError' !== error.name) {
                throw error;
            }
            if (error.headers) {
                Object.keys(error.headers).forEach((header) => {
                    ctx.set(header, error.headers[header]);
                });
            }
            ctx.status = error.statusCode;
            ctx.body = error.message;
        });
    };
}
exports.graphqlKoa = graphqlKoa;
function graphiqlKoa(options) {
    return (ctx) => {
        const q = ctx.request.query || {};
        const query = q.query || '';
        const variables = q.variables || '{}';
        const operationName = q.operationName || '';
        const graphiQLString = GraphiQL.renderGraphiQL({
            endpointURL: options.endpointURL,
            query: query || options.query,
            variables: JSON.parse(variables) || options.variables,
            operationName: operationName || options.operationName,
            passHeader: options.passHeader,
        });
        ctx.set('Content-Type', 'text/html');
        ctx.body = graphiQLString;
    };
}
exports.graphiqlKoa = graphiqlKoa;
//# sourceMappingURL=koaApollo.js.map